@@ -28,6 +28,8 @@
 
 #define SHOW_MSG(x) QApplication::postEvent(parent(), new MessageEvent(x)); EM_PROCESS_EVENTS_NO_INPUT;
 
+#define GIT_LOG_FORMAT "%m%HX%PX%n%cn<%ce>%n%an<%ae>%n%at%n%s%n"
+
 // Used on init() for reading parameters once;
 // It's OK to be unique among qgit windows.
 static bool startup = true;
@@ -181,7 +183,6 @@ bool Git::isThrowOnStopRaised(int excpId, SCRef curContext) {
 
 void Git::setTextCodec(QTextCodec* tc) {
 
-//	QTextCodec::setCodecForCStrings(tc); // works also with tc == 0 (Latin1)
 	QTextCodec::setCodecForLocale(tc);
 	QString name(tc ? tc->name() : "Latin1");
 
@@ -190,7 +191,9 @@ void Git::setTextCodec(QTextCodec* tc) {
 	if (name == "Big5-HKSCS")
 		name = "Big5";
 
-   run("git config i18n.commitencoding " + name);
+	bool dummy;
+	if (tc != getTextCodec(&dummy))
+		run("git config i18n.commitencoding " + name);
 }
 
 QTextCodec* Git::getTextCodec(bool* isGitArchive) {
@@ -200,7 +203,7 @@ QTextCodec* Git::getTextCodec(bool* isGitArchive) {
 		return NULL;
 
 	QString runOutput;
-   if (!run("git config i18n.commitencoding", &runOutput))
+	if (!run("git config i18n.commitencoding", &runOutput))
 		return NULL;
 
 	if (runOutput.isEmpty()) // git docs says default is utf-8
@@ -235,16 +238,13 @@ uint Git::checkRef(SCRef sha, uint mask) const {
 	return (it != refsShaMap.constEnd() ? (*it).type & mask : 0);
 }
 
-const QStringList Git::getRefName(SCRef sha, RefType type, QString* curBranch) const {
+const QStringList Git::getRefName(SCRef sha, RefType type) const {
 
 	if (!checkRef(sha, type))
 		return QStringList();
 
 	const Reference& rf = refsShaMap[toTempSha(sha)];
 
-	if (curBranch)
-		*curBranch = rf.currentBranch;
-
 	if (type == TAG)
 		return rf.tags;
 
@@ -963,9 +963,20 @@ const QString Git::getNewCommitMsg() {
 		dbs("ASSERT: getNewCommitMsg zero_sha not found");
 		return "";
 	}
-
 	QString status = c->longLog();
-	status.prepend('\n').replace(QRegExp("\\n([^#])"), "\n#\\1"); // comment all the lines
+	status.prepend('\n').replace(QRegExp("\\n([^#\\n]?)"), "\n#\\1"); // comment all the lines
+
+	if (isMergeHead) {
+		QFile file(QDir(gitDir).absoluteFilePath("MERGE_MSG"));
+		if (file.open(QIODevice::ReadOnly)) {
+			QTextStream in(&file);
+
+			while(!in.atEnd())
+				status.prepend(in.readLine());
+
+			file.close();
+		}
+	}
 	return status;
 }
 
@@ -1034,8 +1045,9 @@ const QString Git::getDesc(SCRef sha, QRegExp& shortLogRE, QRegExp& longLogRE,
 			<< "</span></th></tr>";
 
 		if (showHeader) {
-		    if (c->committer() != c->author())
-			ts << formatList(QStringList(qt4and5escaping(c->committer())), "Committer");
+			if (c->committer() != c->author())
+				ts << formatList(QStringList(qt4and5escaping(c->committer())), "Committer");
+
 			ts << formatList(QStringList(qt4and5escaping(c->author())), "Author");
 			ts << formatList(QStringList(getLocalDate(c->authorDate())), " Author date");
 
@@ -1081,7 +1093,7 @@ const QString Git::getDesc(SCRef sha, QRegExp& shortLogRE, QRegExp& longLogRE,
 			if (slog.length() > 60)
 				slog = slog.left(57).trimmed().append("...");
 
-			const QString link("<a href=\"" + r->sha() + "\">" + slog.toHtmlEscaped() + "</a>");
+			const QString link("<a href=\"" + r->sha() + "\">" + qt4and5escaping(slog) + "</a>");
 			text.replace(pos + 2, ref.length(), link);
 			pos += link.length();
 		} else
@@ -1559,28 +1571,6 @@ exit:
 	return ret;
 }
 
-bool Git::makeBranch(SCRef sha, SCRef branchName) {
-
-	return run("git branch " + branchName + " " + sha);
-}
-
-bool Git::makeTag(SCRef sha, SCRef tagName, SCRef msg) {
-
-	if (msg.isEmpty())
-		return run("git tag " + tagName + " " + sha);
-
-	return run("git tag -m \"" + msg + "\" " + tagName + " " + sha);
-}
-
-bool Git::deleteTag(SCRef sha) {
-
-	const QStringList tags(getRefName(sha, TAG));
-	if (!tags.empty())
-		return run("git tag -d " + tags.first()); // only one
-
-	return false;
-}
-
 bool Git::stgPush(SCRef sha) {
 
 	const QStringList patch(getRefName(sha, UN_APPLIED));
@@ -1647,12 +1637,15 @@ const QStringList Git::getArgs(bool* quit, bool repoChanged) {
                         args.append(arg + ' ');
                 }
         }
-        if (testFlag(RANGE_SELECT_F) && (!startup || args.isEmpty())) {
-
-                RangeSelectImpl rs((QWidget*)parent(), &args, repoChanged, this);
-                *quit = (rs.exec() == QDialog::Rejected); // modal execution
-                if (*quit)
-                        return QStringList();
+        if (!startup || args.isEmpty()) { // need to retrieve args
+                if (testFlag(RANGE_SELECT_F)) { // open range dialog
+                        RangeSelectImpl rs((QWidget*)parent(), &args, repoChanged, this);
+                        *quit = (rs.exec() == QDialog::Rejected); // modal execution
+                        if (*quit)
+                            return QStringList();
+                } else {
+                    args = RangeSelectImpl::getDefaultArgs();
+                }
         }
         startup = false;
         return MyProcess::splitArgList(args);
@@ -1733,7 +1726,7 @@ bool Git::getRefs() {
 
         // check for a merge and read current branch sha
         isMergeHead = d.exists("MERGE_HEAD");
-        QString curBranchSHA, curBranchName;
+        QString curBranchSHA;
         if (!run("git rev-parse --revs-only HEAD", &curBranchSHA))
                 return false;
 
@@ -1743,6 +1736,8 @@ bool Git::getRefs() {
         curBranchSHA = curBranchSHA.trimmed();
         curBranchName = curBranchName.prepend('\n').section("\n*", 1);
         curBranchName = curBranchName.section('\n', 0, 0).trimmed();
+        if (curBranchName.startsWith("(detached from"))
+            curBranchName = "";
 
         // read refs, normally unsorted
         QString runOutput;
@@ -1802,10 +1797,8 @@ bool Git::getRefs() {
 
                         cur->branches.append(refName.mid(11));
                         cur->type |= BRANCH;
-                        if (curBranchSHA == revSha) {
+                        if (curBranchSHA == revSha)
                                 cur->type |= CUR_BRANCH;
-                                cur->currentBranch = curBranchName;
-                        }
                 } else if (refName.startsWith("refs/remotes/") && !refName.endsWith("HEAD")) {
 
                         cur->remoteBranches.append(refName.mid(13));
@@ -1821,6 +1814,10 @@ bool Git::getRefs() {
         if (isStGIT && !patchNames.isEmpty())
                 parseStGitPatches(patchNames, patchShas);
 
+        // mark current head (even when detached)
+        Reference* cur = lookupOrAddReference(toPersistentSha(curBranchSHA, shaBackupBuf));
+        cur->type |= CUR_BRANCH;
+
         return !refsShaMap.empty();
 }
 
@@ -1888,7 +1885,12 @@ Rev* Git::fakeRevData(SCRef sha, SCList parents, SCRef author, SCRef date, SCRef
         if (!patch.isEmpty())
                 data.append('\n' + patch);
 
-	QByteArray* ba = new QByteArray(data.toLatin1());
+#if QT_VERSION >= 0x050000
+        QTextCodec* tc = QTextCodec::codecForLocale();
+        QByteArray* ba = new QByteArray(tc->fromUnicode(data));
+#else
+        QByteArray* ba = new QByteArray(data.toLatin1());
+#endif
         ba->append('\0');
 
         fh->rowData.append(ba);
@@ -2112,7 +2114,7 @@ bool Git::startRevList(SCList args, FileHistory* fh) {
                         "--log-size " // FIXME broken on Windows
 #endif
                         "--parents --boundary -z "
-                        "--pretty=format:%m%HX%PX%n%cn<%ce>%n%an<%ae>%n%at%n%s%n");
+                        "--pretty=format:" GIT_LOG_FORMAT);
 
         // we don't need log message body for file history
         if (isMainHistory(fh))
@@ -2147,7 +2149,7 @@ bool Git::startUnappliedList() {
 #ifndef Q_OS_WIN32
                     "--log-size " // FIXME broken on Windows
 #endif
-                    "--pretty=format:%m%HX%PX%n%an<%ae>%n%at%n%s%n%b ^HEAD");
+                    "--pretty=format:" GIT_LOG_FORMAT "%b ^HEAD");
 
         QStringList sl(cmd.split(' '));
         sl << unAppliedShaList;
@@ -2248,8 +2250,8 @@ bool Git::init(SCRef wd, bool askForRange, const QStringList* passedArgs, bool o
                 if (!passedArgs) {
 
                         // update text codec according to repo settings
-//                        bool dummy;
-//                        QTextCodec::setCodecForCStrings(getTextCodec(&dummy));
+                        bool dummy;
+                        QTextCodec::setCodecForLocale(getTextCodec(&dummy));
 
                         // load references
                         SHOW_MSG(msg1 + "refs...");
@@ -2771,10 +2773,12 @@ void Git::procFinished() {
 
 void Git::procReadyRead(const QByteArray& fileChunk) {
 
+        QTextCodec* tc = QTextCodec::codecForLocale();
+
         if (filesLoadingPending.isEmpty())
-                filesLoadingPending = fileChunk;
+                filesLoadingPending = tc->toUnicode(fileChunk);
         else
-                filesLoadingPending.append(fileChunk); // add to previous half lines
+                filesLoadingPending.append(tc->toUnicode(fileChunk)); // add to previous half lines
 
         RevFile* rf = NULL;
         if (!filesLoadingCurSha.isEmpty() && revsFiles.contains(toTempSha(filesLoadingCurSha)))
@@ -2815,7 +2819,7 @@ void Git::flushFileNames(FileNamesLoader& fl) {
         QVector<int>& dirs = fl.rfDirs;
 
         b.clear();
-        b.resize(2 * dirs.size() * sizeof(int));
+        b.resize(2 * dirs.size() * static_cast<int>(sizeof(int)));
 
         int* d = (int*)(b.data());
 
