@@ -1035,7 +1035,7 @@ void MainImpl::shortCutActivated() {
 		if (key == Qt::Key_I) {
 			rv->tab()->listViewLog->on_keyUp();
 		}
-		else if (key == (Qt::Key_K or key == Qt::Key_N)) {
+		else if ((key == Qt::Key_K) || (key == Qt::Key_N)) {
 			rv->tab()->listViewLog->on_keyDown();
 		}
 		else if (key == (Qt::SHIFT | Qt::Key_Up)) {
@@ -1062,7 +1062,7 @@ void MainImpl::shortCutActivated() {
 		else if (key == Qt::Key_D) {
 			scrollTextEdit(18); //TODO replace magic constant
 		}
-		else if (key == Qt::Key_Delete or key == Qt::Key_B or key == Qt::Key_Backspace) {
+		else if (key == Qt::Key_Delete || key == Qt::Key_B || key == Qt::Key_Backspace) {
 			scrollTextEdit(-1); //TODO replace magic constant
 		}
 		else if (key == Qt::Key_Space) {
@@ -1071,7 +1071,7 @@ void MainImpl::shortCutActivated() {
 		else if (key == Qt::Key_R) {
 			tabWdg->setCurrentWidget(rv->tabPage());
 		}
-		else if (key == Qt::Key_P or key == Qt::Key_F) {
+		else if (key == Qt::Key_P || key == Qt::Key_F) {
 			QWidget* cp = tabWdg->currentWidget();
 			Domain* d = (key == Qt::Key_P)
 						? static_cast<Domain*>(firstTab<PatchView>(cp))
@@ -1372,7 +1372,7 @@ void MainImpl::goRef_triggered(QAction* act) {
 	if (!act || act->data() != "Ref")
 		return;
 
-	SCRef refSha(git->getRefSha(act->text()));
+	SCRef refSha(git->getRefSha(act->iconText()));
 	rv->st.setSha(refSha);
 	UPDATE_DOMAIN(rv);
 }
@@ -1634,12 +1634,13 @@ void MainImpl::doUpdateCustomActionMenu(const QStringList& list) {
 
 void MainImpl::customAction_triggered(QAction* act) {
 
-	SCRef actionName = act->text();
+	QString actionName = act->text();
 	if (actionName == "Setup actions...")
 		return;
 
 	QSettings set;
-	if (!set.value(ACT_LIST_KEY).toStringList().contains(actionName)) {
+	QStringList actionsList = set.value(ACT_LIST_KEY).toStringList();
+	if (!(actionsList.contains(actionName) || actionsList.contains(actionName.remove(QChar('&'))))) {
 		dbp("ASSERT in customAction_activated, action %1 not found", actionName);
 		return;
 	}
@@ -1734,7 +1735,7 @@ void MainImpl::ActCheckout_activated()
 	const QStringList &local_branches = revision_variables.value(REV_LOCAL_BRANCHES).toStringList();
 
 	if (!selected_name.isEmpty() &&
-	    local_branches.contains(selected_name) > 0 &&
+	    local_branches.contains(selected_name) &&
 	    selected_name != current_branch) {
 		// standard branch switching: directly checkout selected branch
 		rev = selected_name;
@@ -2058,32 +2059,40 @@ void MainImpl::ActAbout_activated() {
 
 	static const char* aboutMsg =
 	"<p><b>QGit version " PACKAGE_VERSION "</b></p>"
-	"<p>Copyright (c) 2005, 2007, 2008 Marco Costalba</p>"
+	"<p>Copyright (c) 2005, 2007, 2008 Marco Costalba<br>"
+	"Copyright (c) 2011-2018 <a href='mailto:tibirna@kde.org'>Cristian Tibirna</a></p>"
 	"<p>Use and redistribute under the terms of the<br>"
 	"<a href=\"http://www.gnu.org/licenses/old-licenses/gpl-2.0.html\">GNU General Public License Version 2</a></p>"
 	"<p>Contributors:<br>"
-	"Copyright (c) 2007 Andy Parkins<br>"
-	"Copyright (c) 2007 Pavel Roskin<br>"
-	"Copyright (c) 2007 Peter Oberndorfer<br>"
-	"Copyright (c) 2007 Yaacov Akiba<br>"
-	"Copyright (c) 2007 James McKaskill<br>"
-	"Copyright (c) 2008 Jan Hudec<br>"
-	"Copyright (c) 2008 Paul Gideon Dann<br>"
-	"Copyright (c) 2008 Oliver Bock<br>"
-	"Copyright (c) 2010 Cyp &lt;cyp561@gmail.com&gt;<br>"
-	"Copyright (c) 2011 Jean-Fran&ccedil;ois Dagenais &lt;dagenaisj@sonatest.com&gt;<br>"
-	"Copyright (c) 2011 Pavel Tikhomirov &lt;pavtih@gmail.com&gt;<br>"
-	"Copyright (c) 2011-2016 Cristian Tibirna &lt;tibirna@kde.org&gt;<br>"
-	"Copyright (c) 2011 Tim Blechmann &lt;tim@klingt.org&gt;<br>"
-	"Copyright (c) 2014 Gregor Mi &lt;codestruct@posteo.org&gt;<br>"
-	"Copyright (c) 2014 Sbytov N.N &lt;sbytnn@gmail.com&gt;<br>"
-	"Copyright (c) 2015 Daniel Levin &lt;dendy.ua@gmail.com&gt;<br>"
-	"Copyright (c) 2017 Luigi Toscano &lt;luigi.toscano@tiscali.it&gt;<br>"
-	"Copyright (c) 2016 Pavel Karelin &lt;hkarel@yandex.ru&gt;<br>"
-	"Copyright (c) 2016 Zane Bitter &lt;zbitter@redhat.com&gt;<br>"
-	"Copyright (c) 2016 Robert Haschke &lt;rhaschke@techfak.uni-bielefeld.de&gt;<br>"
-	"Copyright (c) 2017 Andrey Rahmatullin $lt;wrar@wrar.name&gt;"
-    "</p>"
+	"Copyright (c) "
+	"<nobr>2007 Andy Parkins,</nobr> "
+	"<nobr>2007 Pavel Roskin,</nobr> "
+	"<nobr>2007 Peter Oberndorfer,</nobr> "
+	"<nobr>2007 Yaacov Akiba,</nobr> "
+	"<nobr>2007 James McKaskill,</nobr> "
+	"<nobr>2008 Jan Hudec,</nobr> "
+	"<nobr>2008 Paul Gideon Dann,</nobr> "
+	"<nobr>2008 Oliver Bock,</nobr> "
+	"<nobr>2010 <a href='mailto:cyp561@gmail.com'>Cyp</a>,</nobr> "
+	"<nobr>2011 <a href='dagenaisj@sonatest.com'>Jean-Fran&ccedil;ois Dagenais</a>,</nobr> "
+	"<nobr>2011 <a href='mailto:pavtih@gmail.com'>Pavel Tikhomirov</a>,</nobr> "
+	"<nobr>2011 <a href='mailto:tim@klingt.org'>Tim Blechmann</a>,</nobr> "
+	"<nobr>2014 <a href='mailto:codestruct@posteo.org'>Gregor Mi</a>,</nobr> "
+	"<nobr>2014 <a href='mailto:sbytnn@gmail.com'>Sbytov N.N</a>,</nobr> "
+	"<nobr>2015 <a href='mailto:dendy.ua@gmail.com'>Daniel Levin</a>,</nobr> "
+	"<nobr>2017 <a href='mailto:luigi.toscano@tiscali.it'>Luigi Toscano</a>,</nobr> "
+	"<nobr>2016 <a href='mailto:hkarel@yandex.ru'>Pavel Karelin</a>,</nobr> "
+	"<nobr>2016 <a href='mailto:zbitter@redhat.com'>Zane Bitter</a>,</nobr> "
+	"<nobr>2016 <a href='mailto:rhaschke@techfak.uni-bielefeld.de'>Robert Haschke</a>,</nobr> "
+	"<nobr>2017 <a href='mailto:wrar@wrar.name'>Andrey Rahmatullin</a>,</nobr> "
+	"<nobr>2017 <a href='mailto:alex-github@wenlex.nl'>Alex Hermann</a>,</nobr> "
+	"<nobr>2017 <a href='mailto:shalokshalom@protonmail.ch'>Matthias Schuster</a>,</nobr> "
+	"<nobr>2017 <a href='mailto:u.joss@calltrade.ch'>Urs Joss</a>,</nobr> "
+	"<nobr>2017 <a href='mailto:patrick.m.lacasse@gmail.com'>Patrick Lacasse</a>,</nobr> "
+	"<nobr>2018 <a href='mailto:deveee@gmail.com'>Deve</a>,</nobr> "
+	"<nobr>2018 <a href='mailto:asturm@gentoo.org'>Andreas Sturmlechner</a>,</nobr> "
+	"<nobr>2018 <a href='mailto:kde@davidedmundson.co.uk'>David Edmundson</a></nobr>"
+	"</p>"
 
 	"<p>This version was compiled against Qt " QT_VERSION_STR "</p>";
 	QMessageBox::about(this, "About QGit", QString::fromLatin1(aboutMsg));
